@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::ARODLAND;
 # ABSTRACT: Use L<Dist::Zilla> like ARODLAND does
 our $AUTHORITY = 'cpan:ARODLAND'; # AUTHORITY
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 use 5.10.0;
 use Moose;
@@ -18,7 +18,7 @@ use Dist::Zilla::Plugin::Git::NextVersion;
 #use Dist::Zilla::Plugin::CheckChangesHasContent;
 use Dist::Zilla::Plugin::OurPkgVersion;
 use Dist::Zilla::Plugin::CopyFilesFromBuild;
-use Dist::Zilla::Plugin::ReadmeFromPod;
+use Dist::Zilla::Plugin::ReadmeAnyFromPod;
 use Dist::Zilla::Plugin::Prereqs::FromCPANfile;
 
 sub bundle_config {
@@ -156,12 +156,15 @@ sub bundle_config {
       }
     ],
     [
-      ReadmeFromPod => { }
+      ReadmeAnyFromPod => { 
+        type => 'text',
+        filename => 'README',
+        location => 'root',
+      }
     ],
     [
       CopyFilesFromBuild => {
         copy => [
-          'README',
           ($install_plugin eq 'modulebuild_optionalxs' or $install_plugin eq 'mbtiny'
             ? ('Build.PL')
             : ()
@@ -247,7 +250,7 @@ Dist::Zilla::PluginBundle::ARODLAND - Use L<Dist::Zilla> like ARODLAND does
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 DESCRIPTION
 
